# spec2epsilon - Estimate dielectric constants from fluorescence spectra


[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg?style=plastic)](https://www.python.org/)
[![maint](https://img.shields.io/maintenance/yes/2025?style=plastic)]()
[![commit](https://img.shields.io/github/last-commit/LeonardoESousa/suscs?style=plastic)]()


## How to install it?

`pip install git+https://github.com/LeonardoESousa/spec2epsilon`

## How to use it?

Once installed, use the command:

`spec2epsilon`

The application will open in your browser.
